ICommandLib
===========

The interactive command library.

ICommandLib is a pythonic tool for running UNIX processes in a virtual terminal
and interacting with them. It's sort of like a more advanced pexpect or "selenium
for the command line".

It depends upon CommandLib, which is necessary for defining the commands
which you want to run.

To install:

.. code-block:: sh

    $ pip install icommandlib
